# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DnclistImportStatusImportStatus(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DnclistImportStatusImportStatus - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'import_state': 'str',
            'total_records': 'int',
            'completed_records': 'int',
            'percentage_complete': 'int',
            'failure_reason': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'import_state': 'importState',
            'total_records': 'totalRecords',
            'completed_records': 'completedRecords',
            'percentage_complete': 'percentageComplete',
            'failure_reason': 'failureReason',
            'additional_properties': 'additionalProperties'
        }

        self._import_state = None
        self._total_records = None
        self._completed_records = None
        self._percentage_complete = None
        self._failure_reason = None
        self._additional_properties = None

    @property
    def import_state(self):
        """
        Gets the import_state of this DnclistImportStatusImportStatus.


        :return: The import_state of this DnclistImportStatusImportStatus.
        :rtype: str
        """
        return self._import_state

    @import_state.setter
    def import_state(self, import_state):
        """
        Sets the import_state of this DnclistImportStatusImportStatus.


        :param import_state: The import_state of this DnclistImportStatusImportStatus.
        :type: str
        """
        allowed_values = ["IN_PROGRESS", "FAILED"]
        if import_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for import_state -> " + import_state)
            self._import_state = "outdated_sdk_version"
        else:
            self._import_state = import_state

    @property
    def total_records(self):
        """
        Gets the total_records of this DnclistImportStatusImportStatus.


        :return: The total_records of this DnclistImportStatusImportStatus.
        :rtype: int
        """
        return self._total_records

    @total_records.setter
    def total_records(self, total_records):
        """
        Sets the total_records of this DnclistImportStatusImportStatus.


        :param total_records: The total_records of this DnclistImportStatusImportStatus.
        :type: int
        """
        
        self._total_records = total_records

    @property
    def completed_records(self):
        """
        Gets the completed_records of this DnclistImportStatusImportStatus.


        :return: The completed_records of this DnclistImportStatusImportStatus.
        :rtype: int
        """
        return self._completed_records

    @completed_records.setter
    def completed_records(self, completed_records):
        """
        Sets the completed_records of this DnclistImportStatusImportStatus.


        :param completed_records: The completed_records of this DnclistImportStatusImportStatus.
        :type: int
        """
        
        self._completed_records = completed_records

    @property
    def percentage_complete(self):
        """
        Gets the percentage_complete of this DnclistImportStatusImportStatus.


        :return: The percentage_complete of this DnclistImportStatusImportStatus.
        :rtype: int
        """
        return self._percentage_complete

    @percentage_complete.setter
    def percentage_complete(self, percentage_complete):
        """
        Sets the percentage_complete of this DnclistImportStatusImportStatus.


        :param percentage_complete: The percentage_complete of this DnclistImportStatusImportStatus.
        :type: int
        """
        
        self._percentage_complete = percentage_complete

    @property
    def failure_reason(self):
        """
        Gets the failure_reason of this DnclistImportStatusImportStatus.


        :return: The failure_reason of this DnclistImportStatusImportStatus.
        :rtype: str
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """
        Sets the failure_reason of this DnclistImportStatusImportStatus.


        :param failure_reason: The failure_reason of this DnclistImportStatusImportStatus.
        :type: str
        """
        
        self._failure_reason = failure_reason

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DnclistImportStatusImportStatus.


        :return: The additional_properties of this DnclistImportStatusImportStatus.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DnclistImportStatusImportStatus.


        :param additional_properties: The additional_properties of this DnclistImportStatusImportStatus.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuAgentScheduleActivity(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuAgentScheduleActivity - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'start_date': 'datetime',
            'length_minutes': 'int',
            'description': 'str',
            'activity_code_id': 'str',
            'paid': 'bool',
            'time_off_request_id': 'str',
            'external_activity_id': 'str',
            'external_activity_type': 'str'
        }

        self.attribute_map = {
            'start_date': 'startDate',
            'length_minutes': 'lengthMinutes',
            'description': 'description',
            'activity_code_id': 'activityCodeId',
            'paid': 'paid',
            'time_off_request_id': 'timeOffRequestId',
            'external_activity_id': 'externalActivityId',
            'external_activity_type': 'externalActivityType'
        }

        self._start_date = None
        self._length_minutes = None
        self._description = None
        self._activity_code_id = None
        self._paid = None
        self._time_off_request_id = None
        self._external_activity_id = None
        self._external_activity_type = None

    @property
    def start_date(self):
        """
        Gets the start_date of this BuAgentScheduleActivity.
        The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this BuAgentScheduleActivity.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this BuAgentScheduleActivity.
        The start date/time of this activity. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this BuAgentScheduleActivity.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def length_minutes(self):
        """
        Gets the length_minutes of this BuAgentScheduleActivity.
        The length of this activity in minutes

        :return: The length_minutes of this BuAgentScheduleActivity.
        :rtype: int
        """
        return self._length_minutes

    @length_minutes.setter
    def length_minutes(self, length_minutes):
        """
        Sets the length_minutes of this BuAgentScheduleActivity.
        The length of this activity in minutes

        :param length_minutes: The length_minutes of this BuAgentScheduleActivity.
        :type: int
        """
        
        self._length_minutes = length_minutes

    @property
    def description(self):
        """
        Gets the description of this BuAgentScheduleActivity.
        The description of this activity

        :return: The description of this BuAgentScheduleActivity.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BuAgentScheduleActivity.
        The description of this activity

        :param description: The description of this BuAgentScheduleActivity.
        :type: str
        """
        
        self._description = description

    @property
    def activity_code_id(self):
        """
        Gets the activity_code_id of this BuAgentScheduleActivity.
        The ID of the activity code associated with this activity

        :return: The activity_code_id of this BuAgentScheduleActivity.
        :rtype: str
        """
        return self._activity_code_id

    @activity_code_id.setter
    def activity_code_id(self, activity_code_id):
        """
        Sets the activity_code_id of this BuAgentScheduleActivity.
        The ID of the activity code associated with this activity

        :param activity_code_id: The activity_code_id of this BuAgentScheduleActivity.
        :type: str
        """
        
        self._activity_code_id = activity_code_id

    @property
    def paid(self):
        """
        Gets the paid of this BuAgentScheduleActivity.
        Whether this activity is paid

        :return: The paid of this BuAgentScheduleActivity.
        :rtype: bool
        """
        return self._paid

    @paid.setter
    def paid(self, paid):
        """
        Sets the paid of this BuAgentScheduleActivity.
        Whether this activity is paid

        :param paid: The paid of this BuAgentScheduleActivity.
        :type: bool
        """
        
        self._paid = paid

    @property
    def time_off_request_id(self):
        """
        Gets the time_off_request_id of this BuAgentScheduleActivity.
        The ID of the time off request associated with this activity, if applicable

        :return: The time_off_request_id of this BuAgentScheduleActivity.
        :rtype: str
        """
        return self._time_off_request_id

    @time_off_request_id.setter
    def time_off_request_id(self, time_off_request_id):
        """
        Sets the time_off_request_id of this BuAgentScheduleActivity.
        The ID of the time off request associated with this activity, if applicable

        :param time_off_request_id: The time_off_request_id of this BuAgentScheduleActivity.
        :type: str
        """
        
        self._time_off_request_id = time_off_request_id

    @property
    def external_activity_id(self):
        """
        Gets the external_activity_id of this BuAgentScheduleActivity.
        The ID of the external activity associated with this activity, if applicable

        :return: The external_activity_id of this BuAgentScheduleActivity.
        :rtype: str
        """
        return self._external_activity_id

    @external_activity_id.setter
    def external_activity_id(self, external_activity_id):
        """
        Sets the external_activity_id of this BuAgentScheduleActivity.
        The ID of the external activity associated with this activity, if applicable

        :param external_activity_id: The external_activity_id of this BuAgentScheduleActivity.
        :type: str
        """
        
        self._external_activity_id = external_activity_id

    @property
    def external_activity_type(self):
        """
        Gets the external_activity_type of this BuAgentScheduleActivity.
        The type of the external activity associated with this activity, if applicable

        :return: The external_activity_type of this BuAgentScheduleActivity.
        :rtype: str
        """
        return self._external_activity_type

    @external_activity_type.setter
    def external_activity_type(self, external_activity_type):
        """
        Sets the external_activity_type of this BuAgentScheduleActivity.
        The type of the external activity associated with this activity, if applicable

        :param external_activity_type: The external_activity_type of this BuAgentScheduleActivity.
        :type: str
        """
        allowed_values = ["Coaching"]
        if external_activity_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for external_activity_type -> " + external_activity_type)
            self._external_activity_type = "outdated_sdk_version"
        else:
            self._external_activity_type = external_activity_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicCall(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicCall - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'state': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'error_info': 'QueueConversationEventTopicErrorDetails',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'direction': 'str',
            'document_id': 'str',
            'pcSelf': 'QueueConversationEventTopicAddress',
            'other': 'QueueConversationEventTopicAddress',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[QueueConversationEventTopicDisconnectReason]',
            'fax_status': 'QueueConversationEventTopicFaxStatus',
            'uui_data': 'str',
            'wrapup': 'QueueConversationEventTopicWrapup',
            'after_call_work': 'QueueConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'agent_assistant_id': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'state': 'state',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'direction': 'direction',
            'document_id': 'documentId',
            'pcSelf': 'self',
            'other': 'other',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons',
            'fax_status': 'faxStatus',
            'uui_data': 'uuiData',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'agent_assistant_id': 'agentAssistantId',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._state = None
        self._recording = None
        self._recording_state = None
        self._muted = None
        self._confined = None
        self._held = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._direction = None
        self._document_id = None
        self._pcSelf = None
        self._other = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None
        self._fax_status = None
        self._uui_data = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._agent_assistant_id = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this QueueConversationEventTopicCall.


        :return: The id of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationEventTopicCall.


        :param id: The id of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._id = id

    @property
    def state(self):
        """
        Gets the state of this QueueConversationEventTopicCall.


        :return: The state of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationEventTopicCall.


        :param state: The state of this QueueConversationEventTopicCall.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "UPLOADING", "CONVERTING", "TRANSMITTING", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def recording(self):
        """
        Gets the recording of this QueueConversationEventTopicCall.


        :return: The recording of this QueueConversationEventTopicCall.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this QueueConversationEventTopicCall.


        :param recording: The recording of this QueueConversationEventTopicCall.
        :type: bool
        """
        
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this QueueConversationEventTopicCall.


        :return: The recording_state of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this QueueConversationEventTopicCall.


        :param recording_state: The recording_state of this QueueConversationEventTopicCall.
        :type: str
        """
        allowed_values = ["NONE", "ACTIVE", "PAUSED"]
        if recording_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for recording_state -> " + recording_state)
            self._recording_state = "outdated_sdk_version"
        else:
            self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this QueueConversationEventTopicCall.


        :return: The muted of this QueueConversationEventTopicCall.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this QueueConversationEventTopicCall.


        :param muted: The muted of this QueueConversationEventTopicCall.
        :type: bool
        """
        
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this QueueConversationEventTopicCall.


        :return: The confined of this QueueConversationEventTopicCall.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this QueueConversationEventTopicCall.


        :param confined: The confined of this QueueConversationEventTopicCall.
        :type: bool
        """
        
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this QueueConversationEventTopicCall.


        :return: The held of this QueueConversationEventTopicCall.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this QueueConversationEventTopicCall.


        :param held: The held of this QueueConversationEventTopicCall.
        :type: bool
        """
        
        self._held = held

    @property
    def error_info(self):
        """
        Gets the error_info of this QueueConversationEventTopicCall.


        :return: The error_info of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicErrorDetails
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this QueueConversationEventTopicCall.


        :param error_info: The error_info of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicErrorDetails
        """
        
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationEventTopicCall.


        :return: The disconnect_type of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationEventTopicCall.


        :param disconnect_type: The disconnect_type of this QueueConversationEventTopicCall.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this QueueConversationEventTopicCall.


        :return: The start_hold_time of this QueueConversationEventTopicCall.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this QueueConversationEventTopicCall.


        :param start_hold_time: The start_hold_time of this QueueConversationEventTopicCall.
        :type: datetime
        """
        
        self._start_hold_time = start_hold_time

    @property
    def direction(self):
        """
        Gets the direction of this QueueConversationEventTopicCall.


        :return: The direction of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this QueueConversationEventTopicCall.


        :param direction: The direction of this QueueConversationEventTopicCall.
        :type: str
        """
        allowed_values = ["OUTBOUND", "INBOUND"]
        if direction.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for direction -> " + direction)
            self._direction = "outdated_sdk_version"
        else:
            self._direction = direction

    @property
    def document_id(self):
        """
        Gets the document_id of this QueueConversationEventTopicCall.


        :return: The document_id of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this QueueConversationEventTopicCall.


        :param document_id: The document_id of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._document_id = document_id

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationEventTopicCall.


        :return: The pcSelf of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationEventTopicCall.


        :param pcSelf: The pcSelf of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def other(self):
        """
        Gets the other of this QueueConversationEventTopicCall.


        :return: The other of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicAddress
        """
        return self._other

    @other.setter
    def other(self, other):
        """
        Sets the other of this QueueConversationEventTopicCall.


        :param other: The other of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicAddress
        """
        
        self._other = other

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationEventTopicCall.


        :return: The provider of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationEventTopicCall.


        :param provider: The provider of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationEventTopicCall.


        :return: The script_id of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationEventTopicCall.


        :param script_id: The script_id of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationEventTopicCall.


        :return: The peer_id of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationEventTopicCall.


        :param peer_id: The peer_id of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationEventTopicCall.


        :return: The connected_time of this QueueConversationEventTopicCall.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationEventTopicCall.


        :param connected_time: The connected_time of this QueueConversationEventTopicCall.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationEventTopicCall.


        :return: The disconnected_time of this QueueConversationEventTopicCall.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationEventTopicCall.


        :param disconnected_time: The disconnected_time of this QueueConversationEventTopicCall.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this QueueConversationEventTopicCall.


        :return: The disconnect_reasons of this QueueConversationEventTopicCall.
        :rtype: list[QueueConversationEventTopicDisconnectReason]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this QueueConversationEventTopicCall.


        :param disconnect_reasons: The disconnect_reasons of this QueueConversationEventTopicCall.
        :type: list[QueueConversationEventTopicDisconnectReason]
        """
        
        self._disconnect_reasons = disconnect_reasons

    @property
    def fax_status(self):
        """
        Gets the fax_status of this QueueConversationEventTopicCall.


        :return: The fax_status of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicFaxStatus
        """
        return self._fax_status

    @fax_status.setter
    def fax_status(self, fax_status):
        """
        Sets the fax_status of this QueueConversationEventTopicCall.


        :param fax_status: The fax_status of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicFaxStatus
        """
        
        self._fax_status = fax_status

    @property
    def uui_data(self):
        """
        Gets the uui_data of this QueueConversationEventTopicCall.


        :return: The uui_data of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._uui_data

    @uui_data.setter
    def uui_data(self, uui_data):
        """
        Sets the uui_data of this QueueConversationEventTopicCall.


        :param uui_data: The uui_data of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._uui_data = uui_data

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationEventTopicCall.


        :return: The wrapup of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationEventTopicCall.


        :param wrapup: The wrapup of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationEventTopicCall.


        :return: The after_call_work of this QueueConversationEventTopicCall.
        :rtype: QueueConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationEventTopicCall.


        :param after_call_work: The after_call_work of this QueueConversationEventTopicCall.
        :type: QueueConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationEventTopicCall.


        :return: The after_call_work_required of this QueueConversationEventTopicCall.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationEventTopicCall.


        :param after_call_work_required: The after_call_work_required of this QueueConversationEventTopicCall.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def agent_assistant_id(self):
        """
        Gets the agent_assistant_id of this QueueConversationEventTopicCall.


        :return: The agent_assistant_id of this QueueConversationEventTopicCall.
        :rtype: str
        """
        return self._agent_assistant_id

    @agent_assistant_id.setter
    def agent_assistant_id(self, agent_assistant_id):
        """
        Sets the agent_assistant_id of this QueueConversationEventTopicCall.


        :param agent_assistant_id: The agent_assistant_id of this QueueConversationEventTopicCall.
        :type: str
        """
        
        self._agent_assistant_id = agent_assistant_id

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicCall.


        :return: The additional_properties of this QueueConversationEventTopicCall.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicCall.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicCall.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

import sys
from setuptools import setup, find_packages

NAME = "PureCloudPlatformClientV2"
VERSION = "112.0.1"



# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

REQUIRES = ["urllib3 >= 1.15", "six >= 1.10", "certifi", "python-dateutil"]

setup(
    name="PureCloudPlatformClientV2",
    version="112.0.1",
    description="PureCloud Platform API SDK",
    author="Genesys Developer Evangelists",
    author_email="DeveloperEvangelists@Genesys.com",
    url="https://developer.mypurecloud.com/api/rest/client-libraries/python/",
    keywords=["Swagger PureCloud Platform API Genesys"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="A Python library to interface with the PureCloud Platform API"
)





# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class BuForecastResult(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        BuForecastResult - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'reference_start_date': 'datetime',
            'planning_groups': 'list[ForecastPlanningGroupData]',
            'week_number': 'int',
            'week_count': 'int'
        }

        self.attribute_map = {
            'reference_start_date': 'referenceStartDate',
            'planning_groups': 'planningGroups',
            'week_number': 'weekNumber',
            'week_count': 'weekCount'
        }

        self._reference_start_date = None
        self._planning_groups = None
        self._week_number = None
        self._week_count = None

    @property
    def reference_start_date(self):
        """
        Gets the reference_start_date of this BuForecastResult.
        The reference start date for interval-based data for this forecast. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The reference_start_date of this BuForecastResult.
        :rtype: datetime
        """
        return self._reference_start_date

    @reference_start_date.setter
    def reference_start_date(self, reference_start_date):
        """
        Sets the reference_start_date of this BuForecastResult.
        The reference start date for interval-based data for this forecast. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param reference_start_date: The reference_start_date of this BuForecastResult.
        :type: datetime
        """
        
        self._reference_start_date = reference_start_date

    @property
    def planning_groups(self):
        """
        Gets the planning_groups of this BuForecastResult.
        The forecast data broken up by planning group

        :return: The planning_groups of this BuForecastResult.
        :rtype: list[ForecastPlanningGroupData]
        """
        return self._planning_groups

    @planning_groups.setter
    def planning_groups(self, planning_groups):
        """
        Sets the planning_groups of this BuForecastResult.
        The forecast data broken up by planning group

        :param planning_groups: The planning_groups of this BuForecastResult.
        :type: list[ForecastPlanningGroupData]
        """
        
        self._planning_groups = planning_groups

    @property
    def week_number(self):
        """
        Gets the week_number of this BuForecastResult.
        The week number represented by this response

        :return: The week_number of this BuForecastResult.
        :rtype: int
        """
        return self._week_number

    @week_number.setter
    def week_number(self, week_number):
        """
        Sets the week_number of this BuForecastResult.
        The week number represented by this response

        :param week_number: The week_number of this BuForecastResult.
        :type: int
        """
        
        self._week_number = week_number

    @property
    def week_count(self):
        """
        Gets the week_count of this BuForecastResult.
        The number of weeks in this forecast

        :return: The week_count of this BuForecastResult.
        :rtype: int
        """
        return self._week_count

    @week_count.setter
    def week_count(self, week_count):
        """
        Sets the week_count of this BuForecastResult.
        The number of weeks in this forecast

        :param week_count: The week_count of this BuForecastResult.
        :type: int
        """
        
        self._week_count = week_count

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class KnowledgeTraining(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        KnowledgeTraining - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'date_triggered': 'datetime',
            'date_completed': 'datetime',
            'status': 'str',
            'language_code': 'str',
            'knowledge_base': 'KnowledgeBase',
            'error_message': 'str',
            'knowledge_documents_state': 'str',
            'date_promoted': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'date_triggered': 'dateTriggered',
            'date_completed': 'dateCompleted',
            'status': 'status',
            'language_code': 'languageCode',
            'knowledge_base': 'knowledgeBase',
            'error_message': 'errorMessage',
            'knowledge_documents_state': 'knowledgeDocumentsState',
            'date_promoted': 'datePromoted',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._date_triggered = None
        self._date_completed = None
        self._status = None
        self._language_code = None
        self._knowledge_base = None
        self._error_message = None
        self._knowledge_documents_state = None
        self._date_promoted = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this KnowledgeTraining.
        The globally unique identifier for the object.

        :return: The id of this KnowledgeTraining.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this KnowledgeTraining.
        The globally unique identifier for the object.

        :param id: The id of this KnowledgeTraining.
        :type: str
        """
        
        self._id = id

    @property
    def date_triggered(self):
        """
        Gets the date_triggered of this KnowledgeTraining.
        Trigger date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_triggered of this KnowledgeTraining.
        :rtype: datetime
        """
        return self._date_triggered

    @date_triggered.setter
    def date_triggered(self, date_triggered):
        """
        Sets the date_triggered of this KnowledgeTraining.
        Trigger date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_triggered: The date_triggered of this KnowledgeTraining.
        :type: datetime
        """
        
        self._date_triggered = date_triggered

    @property
    def date_completed(self):
        """
        Gets the date_completed of this KnowledgeTraining.
        Training completed date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_completed of this KnowledgeTraining.
        :rtype: datetime
        """
        return self._date_completed

    @date_completed.setter
    def date_completed(self, date_completed):
        """
        Sets the date_completed of this KnowledgeTraining.
        Training completed date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_completed: The date_completed of this KnowledgeTraining.
        :type: datetime
        """
        
        self._date_completed = date_completed

    @property
    def status(self):
        """
        Gets the status of this KnowledgeTraining.
        Training status.

        :return: The status of this KnowledgeTraining.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this KnowledgeTraining.
        Training status.

        :param status: The status of this KnowledgeTraining.
        :type: str
        """
        allowed_values = ["Queued", "InProgress", "Succeeded", "Failed"]
        if status.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for status -> " + status)
            self._status = "outdated_sdk_version"
        else:
            self._status = status

    @property
    def language_code(self):
        """
        Gets the language_code of this KnowledgeTraining.
        Language of the documents that are trained.

        :return: The language_code of this KnowledgeTraining.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this KnowledgeTraining.
        Language of the documents that are trained.

        :param language_code: The language_code of this KnowledgeTraining.
        :type: str
        """
        
        self._language_code = language_code

    @property
    def knowledge_base(self):
        """
        Gets the knowledge_base of this KnowledgeTraining.
        Knowledge Base that the training belongs to.

        :return: The knowledge_base of this KnowledgeTraining.
        :rtype: KnowledgeBase
        """
        return self._knowledge_base

    @knowledge_base.setter
    def knowledge_base(self, knowledge_base):
        """
        Sets the knowledge_base of this KnowledgeTraining.
        Knowledge Base that the training belongs to.

        :param knowledge_base: The knowledge_base of this KnowledgeTraining.
        :type: KnowledgeBase
        """
        
        self._knowledge_base = knowledge_base

    @property
    def error_message(self):
        """
        Gets the error_message of this KnowledgeTraining.
        Any error message during the Training or Promote action.

        :return: The error_message of this KnowledgeTraining.
        :rtype: str
        """
        return self._error_message

    @error_message.setter
    def error_message(self, error_message):
        """
        Sets the error_message of this KnowledgeTraining.
        Any error message during the Training or Promote action.

        :param error_message: The error_message of this KnowledgeTraining.
        :type: str
        """
        
        self._error_message = error_message

    @property
    def knowledge_documents_state(self):
        """
        Gets the knowledge_documents_state of this KnowledgeTraining.
        State of the Trained Documents, which can be one of these Draft, Active, Discarded, Archived.

        :return: The knowledge_documents_state of this KnowledgeTraining.
        :rtype: str
        """
        return self._knowledge_documents_state

    @knowledge_documents_state.setter
    def knowledge_documents_state(self, knowledge_documents_state):
        """
        Sets the knowledge_documents_state of this KnowledgeTraining.
        State of the Trained Documents, which can be one of these Draft, Active, Discarded, Archived.

        :param knowledge_documents_state: The knowledge_documents_state of this KnowledgeTraining.
        :type: str
        """
        allowed_values = ["Draft", "Active", "Discarded", "Archived"]
        if knowledge_documents_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for knowledge_documents_state -> " + knowledge_documents_state)
            self._knowledge_documents_state = "outdated_sdk_version"
        else:
            self._knowledge_documents_state = knowledge_documents_state

    @property
    def date_promoted(self):
        """
        Gets the date_promoted of this KnowledgeTraining.
        Trained Documents Promoted date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The date_promoted of this KnowledgeTraining.
        :rtype: datetime
        """
        return self._date_promoted

    @date_promoted.setter
    def date_promoted(self, date_promoted):
        """
        Sets the date_promoted of this KnowledgeTraining.
        Trained Documents Promoted date-time. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param date_promoted: The date_promoted of this KnowledgeTraining.
        :type: datetime
        """
        
        self._date_promoted = date_promoted

    @property
    def self_uri(self):
        """
        Gets the self_uri of this KnowledgeTraining.
        The URI for this object

        :return: The self_uri of this KnowledgeTraining.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this KnowledgeTraining.
        The URI for this object

        :param self_uri: The self_uri of this KnowledgeTraining.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class PostTextRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        PostTextRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'bot_id': 'str',
            'bot_alias': 'str',
            'integration_id': 'str',
            'bot_session_id': 'str',
            'post_text_message': 'PostTextMessage',
            'language_code': 'str',
            'bot_session_timeout_minutes': 'int',
            'bot_channels': 'list[str]',
            'bot_correlation_id': 'str',
            'messaging_platform_type': 'str',
            'amazon_lex_request': 'AmazonLexRequest',
            'google_dialogflow': 'GoogleDialogflowCustomSettings',
            'genesys_bot_connector': 'GenesysBotConnector'
        }

        self.attribute_map = {
            'bot_id': 'botId',
            'bot_alias': 'botAlias',
            'integration_id': 'integrationId',
            'bot_session_id': 'botSessionId',
            'post_text_message': 'postTextMessage',
            'language_code': 'languageCode',
            'bot_session_timeout_minutes': 'botSessionTimeoutMinutes',
            'bot_channels': 'botChannels',
            'bot_correlation_id': 'botCorrelationId',
            'messaging_platform_type': 'messagingPlatformType',
            'amazon_lex_request': 'amazonLexRequest',
            'google_dialogflow': 'googleDialogflow',
            'genesys_bot_connector': 'genesysBotConnector'
        }

        self._bot_id = None
        self._bot_alias = None
        self._integration_id = None
        self._bot_session_id = None
        self._post_text_message = None
        self._language_code = None
        self._bot_session_timeout_minutes = None
        self._bot_channels = None
        self._bot_correlation_id = None
        self._messaging_platform_type = None
        self._amazon_lex_request = None
        self._google_dialogflow = None
        self._genesys_bot_connector = None

    @property
    def bot_id(self):
        """
        Gets the bot_id of this PostTextRequest.
        ID of the bot to send the text to.

        :return: The bot_id of this PostTextRequest.
        :rtype: str
        """
        return self._bot_id

    @bot_id.setter
    def bot_id(self, bot_id):
        """
        Sets the bot_id of this PostTextRequest.
        ID of the bot to send the text to.

        :param bot_id: The bot_id of this PostTextRequest.
        :type: str
        """
        
        self._bot_id = bot_id

    @property
    def bot_alias(self):
        """
        Gets the bot_alias of this PostTextRequest.
        Alias/Version of the bot

        :return: The bot_alias of this PostTextRequest.
        :rtype: str
        """
        return self._bot_alias

    @bot_alias.setter
    def bot_alias(self, bot_alias):
        """
        Sets the bot_alias of this PostTextRequest.
        Alias/Version of the bot

        :param bot_alias: The bot_alias of this PostTextRequest.
        :type: str
        """
        
        self._bot_alias = bot_alias

    @property
    def integration_id(self):
        """
        Gets the integration_id of this PostTextRequest.
        the integration service id for the bot's credentials

        :return: The integration_id of this PostTextRequest.
        :rtype: str
        """
        return self._integration_id

    @integration_id.setter
    def integration_id(self, integration_id):
        """
        Sets the integration_id of this PostTextRequest.
        the integration service id for the bot's credentials

        :param integration_id: The integration_id of this PostTextRequest.
        :type: str
        """
        
        self._integration_id = integration_id

    @property
    def bot_session_id(self):
        """
        Gets the bot_session_id of this PostTextRequest.
        GUID for this bot's session

        :return: The bot_session_id of this PostTextRequest.
        :rtype: str
        """
        return self._bot_session_id

    @bot_session_id.setter
    def bot_session_id(self, bot_session_id):
        """
        Sets the bot_session_id of this PostTextRequest.
        GUID for this bot's session

        :param bot_session_id: The bot_session_id of this PostTextRequest.
        :type: str
        """
        
        self._bot_session_id = bot_session_id

    @property
    def post_text_message(self):
        """
        Gets the post_text_message of this PostTextRequest.
        Message to send to the bot

        :return: The post_text_message of this PostTextRequest.
        :rtype: PostTextMessage
        """
        return self._post_text_message

    @post_text_message.setter
    def post_text_message(self, post_text_message):
        """
        Sets the post_text_message of this PostTextRequest.
        Message to send to the bot

        :param post_text_message: The post_text_message of this PostTextRequest.
        :type: PostTextMessage
        """
        
        self._post_text_message = post_text_message

    @property
    def language_code(self):
        """
        Gets the language_code of this PostTextRequest.
        The launguage code the bot will run under

        :return: The language_code of this PostTextRequest.
        :rtype: str
        """
        return self._language_code

    @language_code.setter
    def language_code(self, language_code):
        """
        Sets the language_code of this PostTextRequest.
        The launguage code the bot will run under

        :param language_code: The language_code of this PostTextRequest.
        :type: str
        """
        
        self._language_code = language_code

    @property
    def bot_session_timeout_minutes(self):
        """
        Gets the bot_session_timeout_minutes of this PostTextRequest.
        Override timeout for the bot session. This should be greater than 10 minutes.

        :return: The bot_session_timeout_minutes of this PostTextRequest.
        :rtype: int
        """
        return self._bot_session_timeout_minutes

    @bot_session_timeout_minutes.setter
    def bot_session_timeout_minutes(self, bot_session_timeout_minutes):
        """
        Sets the bot_session_timeout_minutes of this PostTextRequest.
        Override timeout for the bot session. This should be greater than 10 minutes.

        :param bot_session_timeout_minutes: The bot_session_timeout_minutes of this PostTextRequest.
        :type: int
        """
        
        self._bot_session_timeout_minutes = bot_session_timeout_minutes

    @property
    def bot_channels(self):
        """
        Gets the bot_channels of this PostTextRequest.
        The channels this bot is utilizing

        :return: The bot_channels of this PostTextRequest.
        :rtype: list[str]
        """
        return self._bot_channels

    @bot_channels.setter
    def bot_channels(self, bot_channels):
        """
        Sets the bot_channels of this PostTextRequest.
        The channels this bot is utilizing

        :param bot_channels: The bot_channels of this PostTextRequest.
        :type: list[str]
        """
        
        self._bot_channels = bot_channels

    @property
    def bot_correlation_id(self):
        """
        Gets the bot_correlation_id of this PostTextRequest.
        Id for tracking the activity - this will be returned in the response

        :return: The bot_correlation_id of this PostTextRequest.
        :rtype: str
        """
        return self._bot_correlation_id

    @bot_correlation_id.setter
    def bot_correlation_id(self, bot_correlation_id):
        """
        Sets the bot_correlation_id of this PostTextRequest.
        Id for tracking the activity - this will be returned in the response

        :param bot_correlation_id: The bot_correlation_id of this PostTextRequest.
        :type: str
        """
        
        self._bot_correlation_id = bot_correlation_id

    @property
    def messaging_platform_type(self):
        """
        Gets the messaging_platform_type of this PostTextRequest.
        If the channels list contains a 'Messaging' item and the messaging platform is known, include it here to get accurate analytics

        :return: The messaging_platform_type of this PostTextRequest.
        :rtype: str
        """
        return self._messaging_platform_type

    @messaging_platform_type.setter
    def messaging_platform_type(self, messaging_platform_type):
        """
        Sets the messaging_platform_type of this PostTextRequest.
        If the channels list contains a 'Messaging' item and the messaging platform is known, include it here to get accurate analytics

        :param messaging_platform_type: The messaging_platform_type of this PostTextRequest.
        :type: str
        """
        allowed_values = ["Phone", "SMS", "GenesysWebWidget", "FacebookMessenger", "WeChat", "Whatsapp", "AppleBusinessChat", "Telegram", "Slack", "Signal", "Line", "Discord", "TwitterDirectMessage", "Other", "Unknown"]
        if messaging_platform_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for messaging_platform_type -> " + messaging_platform_type)
            self._messaging_platform_type = "outdated_sdk_version"
        else:
            self._messaging_platform_type = messaging_platform_type

    @property
    def amazon_lex_request(self):
        """
        Gets the amazon_lex_request of this PostTextRequest.


        :return: The amazon_lex_request of this PostTextRequest.
        :rtype: AmazonLexRequest
        """
        return self._amazon_lex_request

    @amazon_lex_request.setter
    def amazon_lex_request(self, amazon_lex_request):
        """
        Sets the amazon_lex_request of this PostTextRequest.


        :param amazon_lex_request: The amazon_lex_request of this PostTextRequest.
        :type: AmazonLexRequest
        """
        
        self._amazon_lex_request = amazon_lex_request

    @property
    def google_dialogflow(self):
        """
        Gets the google_dialogflow of this PostTextRequest.


        :return: The google_dialogflow of this PostTextRequest.
        :rtype: GoogleDialogflowCustomSettings
        """
        return self._google_dialogflow

    @google_dialogflow.setter
    def google_dialogflow(self, google_dialogflow):
        """
        Sets the google_dialogflow of this PostTextRequest.


        :param google_dialogflow: The google_dialogflow of this PostTextRequest.
        :type: GoogleDialogflowCustomSettings
        """
        
        self._google_dialogflow = google_dialogflow

    @property
    def genesys_bot_connector(self):
        """
        Gets the genesys_bot_connector of this PostTextRequest.


        :return: The genesys_bot_connector of this PostTextRequest.
        :rtype: GenesysBotConnector
        """
        return self._genesys_bot_connector

    @genesys_bot_connector.setter
    def genesys_bot_connector(self, genesys_bot_connector):
        """
        Sets the genesys_bot_connector of this PostTextRequest.


        :param genesys_bot_connector: The genesys_bot_connector of this PostTextRequest.
        :type: GenesysBotConnector
        """
        
        self._genesys_bot_connector = genesys_bot_connector

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class EffectiveConfiguration(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        EffectiveConfiguration - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'properties': 'dict(str, object)',
            'advanced': 'dict(str, object)',
            'name': 'str',
            'notes': 'str',
            'credentials': 'dict(str, CredentialInfo)'
        }

        self.attribute_map = {
            'properties': 'properties',
            'advanced': 'advanced',
            'name': 'name',
            'notes': 'notes',
            'credentials': 'credentials'
        }

        self._properties = None
        self._advanced = None
        self._name = None
        self._notes = None
        self._credentials = None

    @property
    def properties(self):
        """
        Gets the properties of this EffectiveConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :return: The properties of this EffectiveConfiguration.
        :rtype: dict(str, object)
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """
        Sets the properties of this EffectiveConfiguration.
        Key-value configuration settings described by the schema in the propertiesSchemaUri field.

        :param properties: The properties of this EffectiveConfiguration.
        :type: dict(str, object)
        """
        
        self._properties = properties

    @property
    def advanced(self):
        """
        Gets the advanced of this EffectiveConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :return: The advanced of this EffectiveConfiguration.
        :rtype: dict(str, object)
        """
        return self._advanced

    @advanced.setter
    def advanced(self, advanced):
        """
        Sets the advanced of this EffectiveConfiguration.
        Advanced configuration described by the schema in the advancedSchemaUri field.

        :param advanced: The advanced of this EffectiveConfiguration.
        :type: dict(str, object)
        """
        
        self._advanced = advanced

    @property
    def name(self):
        """
        Gets the name of this EffectiveConfiguration.
        The name of the integration, used to distinguish this integration from others of the same type.

        :return: The name of this EffectiveConfiguration.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this EffectiveConfiguration.
        The name of the integration, used to distinguish this integration from others of the same type.

        :param name: The name of this EffectiveConfiguration.
        :type: str
        """
        
        self._name = name

    @property
    def notes(self):
        """
        Gets the notes of this EffectiveConfiguration.
        Notes about the integration.

        :return: The notes of this EffectiveConfiguration.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this EffectiveConfiguration.
        Notes about the integration.

        :param notes: The notes of this EffectiveConfiguration.
        :type: str
        """
        
        self._notes = notes

    @property
    def credentials(self):
        """
        Gets the credentials of this EffectiveConfiguration.
        Credentials required by the integration. The required keys are indicated in the credentials property of the Integration Type

        :return: The credentials of this EffectiveConfiguration.
        :rtype: dict(str, CredentialInfo)
        """
        return self._credentials

    @credentials.setter
    def credentials(self, credentials):
        """
        Sets the credentials of this EffectiveConfiguration.
        Credentials required by the integration. The required keys are indicated in the credentials property of the Integration Type

        :param credentials: The credentials of this EffectiveConfiguration.
        :type: dict(str, CredentialInfo)
        """
        
        self._credentials = credentials

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicScreenshare(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicScreenshare - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'pcSelf': 'QueueConversationEventTopicAddress',
            'id': 'str',
            'context': 'str',
            'sharing': 'bool',
            'provider': 'str',
            'script_id': 'str',
            'peer_id': 'str',
            'disconnect_type': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'wrapup': 'QueueConversationEventTopicWrapup',
            'after_call_work': 'QueueConversationEventTopicAfterCallWork',
            'after_call_work_required': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'state': 'state',
            'pcSelf': 'self',
            'id': 'id',
            'context': 'context',
            'sharing': 'sharing',
            'provider': 'provider',
            'script_id': 'scriptId',
            'peer_id': 'peerId',
            'disconnect_type': 'disconnectType',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'wrapup': 'wrapup',
            'after_call_work': 'afterCallWork',
            'after_call_work_required': 'afterCallWorkRequired',
            'additional_properties': 'additionalProperties'
        }

        self._state = None
        self._pcSelf = None
        self._id = None
        self._context = None
        self._sharing = None
        self._provider = None
        self._script_id = None
        self._peer_id = None
        self._disconnect_type = None
        self._connected_time = None
        self._disconnected_time = None
        self._wrapup = None
        self._after_call_work = None
        self._after_call_work_required = None
        self._additional_properties = None

    @property
    def state(self):
        """
        Gets the state of this QueueConversationEventTopicScreenshare.


        :return: The state of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this QueueConversationEventTopicScreenshare.


        :param state: The state of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "NONE"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def pcSelf(self):
        """
        Gets the pcSelf of this QueueConversationEventTopicScreenshare.


        :return: The pcSelf of this QueueConversationEventTopicScreenshare.
        :rtype: QueueConversationEventTopicAddress
        """
        return self._pcSelf

    @pcSelf.setter
    def pcSelf(self, pcSelf):
        """
        Sets the pcSelf of this QueueConversationEventTopicScreenshare.


        :param pcSelf: The pcSelf of this QueueConversationEventTopicScreenshare.
        :type: QueueConversationEventTopicAddress
        """
        
        self._pcSelf = pcSelf

    @property
    def id(self):
        """
        Gets the id of this QueueConversationEventTopicScreenshare.


        :return: The id of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QueueConversationEventTopicScreenshare.


        :param id: The id of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        
        self._id = id

    @property
    def context(self):
        """
        Gets the context of this QueueConversationEventTopicScreenshare.


        :return: The context of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._context

    @context.setter
    def context(self, context):
        """
        Sets the context of this QueueConversationEventTopicScreenshare.


        :param context: The context of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        
        self._context = context

    @property
    def sharing(self):
        """
        Gets the sharing of this QueueConversationEventTopicScreenshare.


        :return: The sharing of this QueueConversationEventTopicScreenshare.
        :rtype: bool
        """
        return self._sharing

    @sharing.setter
    def sharing(self, sharing):
        """
        Sets the sharing of this QueueConversationEventTopicScreenshare.


        :param sharing: The sharing of this QueueConversationEventTopicScreenshare.
        :type: bool
        """
        
        self._sharing = sharing

    @property
    def provider(self):
        """
        Gets the provider of this QueueConversationEventTopicScreenshare.


        :return: The provider of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._provider

    @provider.setter
    def provider(self, provider):
        """
        Sets the provider of this QueueConversationEventTopicScreenshare.


        :param provider: The provider of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        
        self._provider = provider

    @property
    def script_id(self):
        """
        Gets the script_id of this QueueConversationEventTopicScreenshare.


        :return: The script_id of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._script_id

    @script_id.setter
    def script_id(self, script_id):
        """
        Sets the script_id of this QueueConversationEventTopicScreenshare.


        :param script_id: The script_id of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        
        self._script_id = script_id

    @property
    def peer_id(self):
        """
        Gets the peer_id of this QueueConversationEventTopicScreenshare.


        :return: The peer_id of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._peer_id

    @peer_id.setter
    def peer_id(self, peer_id):
        """
        Sets the peer_id of this QueueConversationEventTopicScreenshare.


        :param peer_id: The peer_id of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        
        self._peer_id = peer_id

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this QueueConversationEventTopicScreenshare.


        :return: The disconnect_type of this QueueConversationEventTopicScreenshare.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this QueueConversationEventTopicScreenshare.


        :param disconnect_type: The disconnect_type of this QueueConversationEventTopicScreenshare.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "TRANSFER_NOANSWER", "TRANSFER_NOTAVAILABLE", "TRANSPORT_FAILURE", "ERROR", "PEER", "OTHER", "SPAM", "UNCALLABLE"]
        if disconnect_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for disconnect_type -> " + disconnect_type)
            self._disconnect_type = "outdated_sdk_version"
        else:
            self._disconnect_type = disconnect_type

    @property
    def connected_time(self):
        """
        Gets the connected_time of this QueueConversationEventTopicScreenshare.


        :return: The connected_time of this QueueConversationEventTopicScreenshare.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this QueueConversationEventTopicScreenshare.


        :param connected_time: The connected_time of this QueueConversationEventTopicScreenshare.
        :type: datetime
        """
        
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this QueueConversationEventTopicScreenshare.


        :return: The disconnected_time of this QueueConversationEventTopicScreenshare.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this QueueConversationEventTopicScreenshare.


        :param disconnected_time: The disconnected_time of this QueueConversationEventTopicScreenshare.
        :type: datetime
        """
        
        self._disconnected_time = disconnected_time

    @property
    def wrapup(self):
        """
        Gets the wrapup of this QueueConversationEventTopicScreenshare.


        :return: The wrapup of this QueueConversationEventTopicScreenshare.
        :rtype: QueueConversationEventTopicWrapup
        """
        return self._wrapup

    @wrapup.setter
    def wrapup(self, wrapup):
        """
        Sets the wrapup of this QueueConversationEventTopicScreenshare.


        :param wrapup: The wrapup of this QueueConversationEventTopicScreenshare.
        :type: QueueConversationEventTopicWrapup
        """
        
        self._wrapup = wrapup

    @property
    def after_call_work(self):
        """
        Gets the after_call_work of this QueueConversationEventTopicScreenshare.


        :return: The after_call_work of this QueueConversationEventTopicScreenshare.
        :rtype: QueueConversationEventTopicAfterCallWork
        """
        return self._after_call_work

    @after_call_work.setter
    def after_call_work(self, after_call_work):
        """
        Sets the after_call_work of this QueueConversationEventTopicScreenshare.


        :param after_call_work: The after_call_work of this QueueConversationEventTopicScreenshare.
        :type: QueueConversationEventTopicAfterCallWork
        """
        
        self._after_call_work = after_call_work

    @property
    def after_call_work_required(self):
        """
        Gets the after_call_work_required of this QueueConversationEventTopicScreenshare.


        :return: The after_call_work_required of this QueueConversationEventTopicScreenshare.
        :rtype: bool
        """
        return self._after_call_work_required

    @after_call_work_required.setter
    def after_call_work_required(self, after_call_work_required):
        """
        Sets the after_call_work_required of this QueueConversationEventTopicScreenshare.


        :param after_call_work_required: The after_call_work_required of this QueueConversationEventTopicScreenshare.
        :type: bool
        """
        
        self._after_call_work_required = after_call_work_required

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicScreenshare.


        :return: The additional_properties of this QueueConversationEventTopicScreenshare.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicScreenshare.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicScreenshare.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AdherenceSettings(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AdherenceSettings - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'severe_alert_threshold_minutes': 'int',
            'adherence_target_percent': 'int',
            'adherence_exception_threshold_seconds': 'int',
            'non_on_queue_activities_equivalent': 'bool',
            'track_on_queue_activity': 'bool',
            'ignored_activity_categories': 'IgnoredActivityCategories'
        }

        self.attribute_map = {
            'severe_alert_threshold_minutes': 'severeAlertThresholdMinutes',
            'adherence_target_percent': 'adherenceTargetPercent',
            'adherence_exception_threshold_seconds': 'adherenceExceptionThresholdSeconds',
            'non_on_queue_activities_equivalent': 'nonOnQueueActivitiesEquivalent',
            'track_on_queue_activity': 'trackOnQueueActivity',
            'ignored_activity_categories': 'ignoredActivityCategories'
        }

        self._severe_alert_threshold_minutes = None
        self._adherence_target_percent = None
        self._adherence_exception_threshold_seconds = None
        self._non_on_queue_activities_equivalent = None
        self._track_on_queue_activity = None
        self._ignored_activity_categories = None

    @property
    def severe_alert_threshold_minutes(self):
        """
        Gets the severe_alert_threshold_minutes of this AdherenceSettings.
        The threshold in minutes where an alert will be triggered when an agent is considered severely out of adherence

        :return: The severe_alert_threshold_minutes of this AdherenceSettings.
        :rtype: int
        """
        return self._severe_alert_threshold_minutes

    @severe_alert_threshold_minutes.setter
    def severe_alert_threshold_minutes(self, severe_alert_threshold_minutes):
        """
        Sets the severe_alert_threshold_minutes of this AdherenceSettings.
        The threshold in minutes where an alert will be triggered when an agent is considered severely out of adherence

        :param severe_alert_threshold_minutes: The severe_alert_threshold_minutes of this AdherenceSettings.
        :type: int
        """
        
        self._severe_alert_threshold_minutes = severe_alert_threshold_minutes

    @property
    def adherence_target_percent(self):
        """
        Gets the adherence_target_percent of this AdherenceSettings.
        Target adherence percentage

        :return: The adherence_target_percent of this AdherenceSettings.
        :rtype: int
        """
        return self._adherence_target_percent

    @adherence_target_percent.setter
    def adherence_target_percent(self, adherence_target_percent):
        """
        Sets the adherence_target_percent of this AdherenceSettings.
        Target adherence percentage

        :param adherence_target_percent: The adherence_target_percent of this AdherenceSettings.
        :type: int
        """
        
        self._adherence_target_percent = adherence_target_percent

    @property
    def adherence_exception_threshold_seconds(self):
        """
        Gets the adherence_exception_threshold_seconds of this AdherenceSettings.
        The threshold in seconds for which agents should not be penalized for being momentarily out of adherence

        :return: The adherence_exception_threshold_seconds of this AdherenceSettings.
        :rtype: int
        """
        return self._adherence_exception_threshold_seconds

    @adherence_exception_threshold_seconds.setter
    def adherence_exception_threshold_seconds(self, adherence_exception_threshold_seconds):
        """
        Sets the adherence_exception_threshold_seconds of this AdherenceSettings.
        The threshold in seconds for which agents should not be penalized for being momentarily out of adherence

        :param adherence_exception_threshold_seconds: The adherence_exception_threshold_seconds of this AdherenceSettings.
        :type: int
        """
        
        self._adherence_exception_threshold_seconds = adherence_exception_threshold_seconds

    @property
    def non_on_queue_activities_equivalent(self):
        """
        Gets the non_on_queue_activities_equivalent of this AdherenceSettings.
        Whether to treat all non-on-queue activities as equivalent for adherence purposes

        :return: The non_on_queue_activities_equivalent of this AdherenceSettings.
        :rtype: bool
        """
        return self._non_on_queue_activities_equivalent

    @non_on_queue_activities_equivalent.setter
    def non_on_queue_activities_equivalent(self, non_on_queue_activities_equivalent):
        """
        Sets the non_on_queue_activities_equivalent of this AdherenceSettings.
        Whether to treat all non-on-queue activities as equivalent for adherence purposes

        :param non_on_queue_activities_equivalent: The non_on_queue_activities_equivalent of this AdherenceSettings.
        :type: bool
        """
        
        self._non_on_queue_activities_equivalent = non_on_queue_activities_equivalent

    @property
    def track_on_queue_activity(self):
        """
        Gets the track_on_queue_activity of this AdherenceSettings.
        Whether to track on-queue activities

        :return: The track_on_queue_activity of this AdherenceSettings.
        :rtype: bool
        """
        return self._track_on_queue_activity

    @track_on_queue_activity.setter
    def track_on_queue_activity(self, track_on_queue_activity):
        """
        Sets the track_on_queue_activity of this AdherenceSettings.
        Whether to track on-queue activities

        :param track_on_queue_activity: The track_on_queue_activity of this AdherenceSettings.
        :type: bool
        """
        
        self._track_on_queue_activity = track_on_queue_activity

    @property
    def ignored_activity_categories(self):
        """
        Gets the ignored_activity_categories of this AdherenceSettings.
        Activity categories that should be ignored for adherence purposes

        :return: The ignored_activity_categories of this AdherenceSettings.
        :rtype: IgnoredActivityCategories
        """
        return self._ignored_activity_categories

    @ignored_activity_categories.setter
    def ignored_activity_categories(self, ignored_activity_categories):
        """
        Sets the ignored_activity_categories of this AdherenceSettings.
        Activity categories that should be ignored for adherence purposes

        :param ignored_activity_categories: The ignored_activity_categories of this AdherenceSettings.
        :type: IgnoredActivityCategories
        """
        
        self._ignored_activity_categories = ignored_activity_categories

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmUserNotificationTopicShiftTradeNotification(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmUserNotificationTopicShiftTradeNotification - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'week_date': 'str',
            'trade_id': 'str',
            'one_sided': 'bool',
            'new_state': 'str',
            'initiating_user': 'WfmUserNotificationTopicUserReference',
            'initiating_shift_date': 'datetime',
            'receiving_user': 'WfmUserNotificationTopicUserReference',
            'receiving_shift_date': 'datetime'
        }

        self.attribute_map = {
            'week_date': 'weekDate',
            'trade_id': 'tradeId',
            'one_sided': 'oneSided',
            'new_state': 'newState',
            'initiating_user': 'initiatingUser',
            'initiating_shift_date': 'initiatingShiftDate',
            'receiving_user': 'receivingUser',
            'receiving_shift_date': 'receivingShiftDate'
        }

        self._week_date = None
        self._trade_id = None
        self._one_sided = None
        self._new_state = None
        self._initiating_user = None
        self._initiating_shift_date = None
        self._receiving_user = None
        self._receiving_shift_date = None

    @property
    def week_date(self):
        """
        Gets the week_date of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The week_date of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: str
        """
        return self._week_date

    @week_date.setter
    def week_date(self, week_date):
        """
        Sets the week_date of this WfmUserNotificationTopicShiftTradeNotification.


        :param week_date: The week_date of this WfmUserNotificationTopicShiftTradeNotification.
        :type: str
        """
        
        self._week_date = week_date

    @property
    def trade_id(self):
        """
        Gets the trade_id of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The trade_id of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: str
        """
        return self._trade_id

    @trade_id.setter
    def trade_id(self, trade_id):
        """
        Sets the trade_id of this WfmUserNotificationTopicShiftTradeNotification.


        :param trade_id: The trade_id of this WfmUserNotificationTopicShiftTradeNotification.
        :type: str
        """
        
        self._trade_id = trade_id

    @property
    def one_sided(self):
        """
        Gets the one_sided of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The one_sided of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: bool
        """
        return self._one_sided

    @one_sided.setter
    def one_sided(self, one_sided):
        """
        Sets the one_sided of this WfmUserNotificationTopicShiftTradeNotification.


        :param one_sided: The one_sided of this WfmUserNotificationTopicShiftTradeNotification.
        :type: bool
        """
        
        self._one_sided = one_sided

    @property
    def new_state(self):
        """
        Gets the new_state of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The new_state of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: str
        """
        return self._new_state

    @new_state.setter
    def new_state(self, new_state):
        """
        Sets the new_state of this WfmUserNotificationTopicShiftTradeNotification.


        :param new_state: The new_state of this WfmUserNotificationTopicShiftTradeNotification.
        :type: str
        """
        allowed_values = ["Unmatched", "Matched", "Approved", "Denied", "Expired", "Canceled"]
        if new_state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for new_state -> " + new_state)
            self._new_state = "outdated_sdk_version"
        else:
            self._new_state = new_state

    @property
    def initiating_user(self):
        """
        Gets the initiating_user of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The initiating_user of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: WfmUserNotificationTopicUserReference
        """
        return self._initiating_user

    @initiating_user.setter
    def initiating_user(self, initiating_user):
        """
        Sets the initiating_user of this WfmUserNotificationTopicShiftTradeNotification.


        :param initiating_user: The initiating_user of this WfmUserNotificationTopicShiftTradeNotification.
        :type: WfmUserNotificationTopicUserReference
        """
        
        self._initiating_user = initiating_user

    @property
    def initiating_shift_date(self):
        """
        Gets the initiating_shift_date of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The initiating_shift_date of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: datetime
        """
        return self._initiating_shift_date

    @initiating_shift_date.setter
    def initiating_shift_date(self, initiating_shift_date):
        """
        Sets the initiating_shift_date of this WfmUserNotificationTopicShiftTradeNotification.


        :param initiating_shift_date: The initiating_shift_date of this WfmUserNotificationTopicShiftTradeNotification.
        :type: datetime
        """
        
        self._initiating_shift_date = initiating_shift_date

    @property
    def receiving_user(self):
        """
        Gets the receiving_user of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The receiving_user of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: WfmUserNotificationTopicUserReference
        """
        return self._receiving_user

    @receiving_user.setter
    def receiving_user(self, receiving_user):
        """
        Sets the receiving_user of this WfmUserNotificationTopicShiftTradeNotification.


        :param receiving_user: The receiving_user of this WfmUserNotificationTopicShiftTradeNotification.
        :type: WfmUserNotificationTopicUserReference
        """
        
        self._receiving_user = receiving_user

    @property
    def receiving_shift_date(self):
        """
        Gets the receiving_shift_date of this WfmUserNotificationTopicShiftTradeNotification.


        :return: The receiving_shift_date of this WfmUserNotificationTopicShiftTradeNotification.
        :rtype: datetime
        """
        return self._receiving_shift_date

    @receiving_shift_date.setter
    def receiving_shift_date(self, receiving_shift_date):
        """
        Sets the receiving_shift_date of this WfmUserNotificationTopicShiftTradeNotification.


        :param receiving_shift_date: The receiving_shift_date of this WfmUserNotificationTopicShiftTradeNotification.
        :type: datetime
        """
        
        self._receiving_shift_date = receiving_shift_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Organization(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Organization - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'default_language': 'str',
            'default_country_code': 'str',
            'third_party_org_name': 'str',
            'third_party_uri': 'str',
            'domain': 'str',
            'version': 'int',
            'state': 'str',
            'default_site_id': 'str',
            'support_uri': 'str',
            'voicemail_enabled': 'bool',
            'product_platform': 'str',
            'self_uri': 'str',
            'features': 'dict(str, bool)'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'default_language': 'defaultLanguage',
            'default_country_code': 'defaultCountryCode',
            'third_party_org_name': 'thirdPartyOrgName',
            'third_party_uri': 'thirdPartyURI',
            'domain': 'domain',
            'version': 'version',
            'state': 'state',
            'default_site_id': 'defaultSiteId',
            'support_uri': 'supportURI',
            'voicemail_enabled': 'voicemailEnabled',
            'product_platform': 'productPlatform',
            'self_uri': 'selfUri',
            'features': 'features'
        }

        self._id = None
        self._name = None
        self._default_language = None
        self._default_country_code = None
        self._third_party_org_name = None
        self._third_party_uri = None
        self._domain = None
        self._version = None
        self._state = None
        self._default_site_id = None
        self._support_uri = None
        self._voicemail_enabled = None
        self._product_platform = None
        self._self_uri = None
        self._features = None

    @property
    def id(self):
        """
        Gets the id of this Organization.
        The globally unique identifier for the object.

        :return: The id of this Organization.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Organization.
        The globally unique identifier for the object.

        :param id: The id of this Organization.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Organization.


        :return: The name of this Organization.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Organization.


        :param name: The name of this Organization.
        :type: str
        """
        
        self._name = name

    @property
    def default_language(self):
        """
        Gets the default_language of this Organization.
        The default language for this organization. Example: 'en'

        :return: The default_language of this Organization.
        :rtype: str
        """
        return self._default_language

    @default_language.setter
    def default_language(self, default_language):
        """
        Sets the default_language of this Organization.
        The default language for this organization. Example: 'en'

        :param default_language: The default_language of this Organization.
        :type: str
        """
        
        self._default_language = default_language

    @property
    def default_country_code(self):
        """
        Gets the default_country_code of this Organization.
        The default country code for this organization. Example: 'US'

        :return: The default_country_code of this Organization.
        :rtype: str
        """
        return self._default_country_code

    @default_country_code.setter
    def default_country_code(self, default_country_code):
        """
        Sets the default_country_code of this Organization.
        The default country code for this organization. Example: 'US'

        :param default_country_code: The default_country_code of this Organization.
        :type: str
        """
        
        self._default_country_code = default_country_code

    @property
    def third_party_org_name(self):
        """
        Gets the third_party_org_name of this Organization.
        The short name for the organization. This field is globally unique and cannot be changed.

        :return: The third_party_org_name of this Organization.
        :rtype: str
        """
        return self._third_party_org_name

    @third_party_org_name.setter
    def third_party_org_name(self, third_party_org_name):
        """
        Sets the third_party_org_name of this Organization.
        The short name for the organization. This field is globally unique and cannot be changed.

        :param third_party_org_name: The third_party_org_name of this Organization.
        :type: str
        """
        
        self._third_party_org_name = third_party_org_name

    @property
    def third_party_uri(self):
        """
        Gets the third_party_uri of this Organization.


        :return: The third_party_uri of this Organization.
        :rtype: str
        """
        return self._third_party_uri

    @third_party_uri.setter
    def third_party_uri(self, third_party_uri):
        """
        Sets the third_party_uri of this Organization.


        :param third_party_uri: The third_party_uri of this Organization.
        :type: str
        """
        
        self._third_party_uri = third_party_uri

    @property
    def domain(self):
        """
        Gets the domain of this Organization.


        :return: The domain of this Organization.
        :rtype: str
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """
        Sets the domain of this Organization.


        :param domain: The domain of this Organization.
        :type: str
        """
        
        self._domain = domain

    @property
    def version(self):
        """
        Gets the version of this Organization.
        The current version of the organization.

        :return: The version of this Organization.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this Organization.
        The current version of the organization.

        :param version: The version of this Organization.
        :type: int
        """
        
        self._version = version

    @property
    def state(self):
        """
        Gets the state of this Organization.
        The current state. Examples are active, inactive, deleted.

        :return: The state of this Organization.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Organization.
        The current state. Examples are active, inactive, deleted.

        :param state: The state of this Organization.
        :type: str
        """
        allowed_values = ["active", "inactive", "deleted"]
        if state.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for state -> " + state)
            self._state = "outdated_sdk_version"
        else:
            self._state = state

    @property
    def default_site_id(self):
        """
        Gets the default_site_id of this Organization.


        :return: The default_site_id of this Organization.
        :rtype: str
        """
        return self._default_site_id

    @default_site_id.setter
    def default_site_id(self, default_site_id):
        """
        Sets the default_site_id of this Organization.


        :param default_site_id: The default_site_id of this Organization.
        :type: str
        """
        
        self._default_site_id = default_site_id

    @property
    def support_uri(self):
        """
        Gets the support_uri of this Organization.
        Email address where support tickets are sent to.

        :return: The support_uri of this Organization.
        :rtype: str
        """
        return self._support_uri

    @support_uri.setter
    def support_uri(self, support_uri):
        """
        Sets the support_uri of this Organization.
        Email address where support tickets are sent to.

        :param support_uri: The support_uri of this Organization.
        :type: str
        """
        
        self._support_uri = support_uri

    @property
    def voicemail_enabled(self):
        """
        Gets the voicemail_enabled of this Organization.


        :return: The voicemail_enabled of this Organization.
        :rtype: bool
        """
        return self._voicemail_enabled

    @voicemail_enabled.setter
    def voicemail_enabled(self, voicemail_enabled):
        """
        Sets the voicemail_enabled of this Organization.


        :param voicemail_enabled: The voicemail_enabled of this Organization.
        :type: bool
        """
        
        self._voicemail_enabled = voicemail_enabled

    @property
    def product_platform(self):
        """
        Gets the product_platform of this Organization.
        Organizations Originating Platform.

        :return: The product_platform of this Organization.
        :rtype: str
        """
        return self._product_platform

    @product_platform.setter
    def product_platform(self, product_platform):
        """
        Sets the product_platform of this Organization.
        Organizations Originating Platform.

        :param product_platform: The product_platform of this Organization.
        :type: str
        """
        allowed_values = ["GenesysCloud", "PureCloud", "PureEngage", "PureEngageCloud", "PureConnect", "PureConnectCloud", "Unknown"]
        if product_platform.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for product_platform -> " + product_platform)
            self._product_platform = "outdated_sdk_version"
        else:
            self._product_platform = product_platform

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Organization.
        The URI for this object

        :return: The self_uri of this Organization.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Organization.
        The URI for this object

        :param self_uri: The self_uri of this Organization.
        :type: str
        """
        
        self._self_uri = self_uri

    @property
    def features(self):
        """
        Gets the features of this Organization.
        The state of features available for the organization.

        :return: The features of this Organization.
        :rtype: dict(str, bool)
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this Organization.
        The state of features available for the organization.

        :param features: The features of this Organization.
        :type: dict(str, bool)
        """
        
        self._features = features

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class ListItemComponent(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ListItemComponent - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'rmid': 'str',
            'type': 'str',
            'image': 'str',
            'title': 'str',
            'description': 'str',
            'actions': 'ContentActions'
        }

        self.attribute_map = {
            'id': 'id',
            'rmid': 'rmid',
            'type': 'type',
            'image': 'image',
            'title': 'title',
            'description': 'description',
            'actions': 'actions'
        }

        self._id = None
        self._rmid = None
        self._type = None
        self._image = None
        self._title = None
        self._description = None
        self._actions = None

    @property
    def id(self):
        """
        Gets the id of this ListItemComponent.
        An ID assigned to this component

        :return: The id of this ListItemComponent.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ListItemComponent.
        An ID assigned to this component

        :param id: The id of this ListItemComponent.
        :type: str
        """
        
        self._id = id

    @property
    def rmid(self):
        """
        Gets the rmid of this ListItemComponent.
        An ID of the rich message instance

        :return: The rmid of this ListItemComponent.
        :rtype: str
        """
        return self._rmid

    @rmid.setter
    def rmid(self, rmid):
        """
        Sets the rmid of this ListItemComponent.
        An ID of the rich message instance

        :param rmid: The rmid of this ListItemComponent.
        :type: str
        """
        
        self._rmid = rmid

    @property
    def type(self):
        """
        Gets the type of this ListItemComponent.
        The type of component to render

        :return: The type of this ListItemComponent.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ListItemComponent.
        The type of component to render

        :param type: The type of this ListItemComponent.
        :type: str
        """
        allowed_values = ["ListItem", "ListItemBig"]
        if type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for type -> " + type)
            self._type = "outdated_sdk_version"
        else:
            self._type = type

    @property
    def image(self):
        """
        Gets the image of this ListItemComponent.
        Path or URI to an image file

        :return: The image of this ListItemComponent.
        :rtype: str
        """
        return self._image

    @image.setter
    def image(self, image):
        """
        Sets the image of this ListItemComponent.
        Path or URI to an image file

        :param image: The image of this ListItemComponent.
        :type: str
        """
        
        self._image = image

    @property
    def title(self):
        """
        Gets the title of this ListItemComponent.
        The main headline of the list item

        :return: The title of this ListItemComponent.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this ListItemComponent.
        The main headline of the list item

        :param title: The title of this ListItemComponent.
        :type: str
        """
        
        self._title = title

    @property
    def description(self):
        """
        Gets the description of this ListItemComponent.
        Text to show in the description row

        :return: The description of this ListItemComponent.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ListItemComponent.
        Text to show in the description row

        :param description: The description of this ListItemComponent.
        :type: str
        """
        
        self._description = description

    @property
    def actions(self):
        """
        Gets the actions of this ListItemComponent.
        User actions available on the content. All actions are optional and all actions are executed simultaneously.

        :return: The actions of this ListItemComponent.
        :rtype: ContentActions
        """
        return self._actions

    @actions.setter
    def actions(self, actions):
        """
        Sets the actions of this ListItemComponent.
        User actions available on the content. All actions are optional and all actions are executed simultaneously.

        :param actions: The actions of this ListItemComponent.
        :type: ContentActions
        """
        
        self._actions = actions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WorkPlanListItemResponse(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkPlanListItemResponse - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'enabled': 'bool',
            'constrain_weekly_paid_time': 'bool',
            'flexible_weekly_paid_time': 'bool',
            'weekly_exact_paid_minutes': 'int',
            'weekly_minimum_paid_minutes': 'int',
            'weekly_maximum_paid_minutes': 'int',
            'constrain_paid_time_granularity': 'bool',
            'paid_time_granularity_minutes': 'int',
            'constrain_minimum_time_between_shifts': 'bool',
            'minimum_time_between_shifts_minutes': 'int',
            'maximum_days': 'int',
            'minimum_consecutive_non_working_minutes_per_week': 'int',
            'constrain_maximum_consecutive_working_weekends': 'bool',
            'maximum_consecutive_working_weekends': 'int',
            'minimum_working_days_per_week': 'int',
            'constrain_maximum_consecutive_working_days': 'bool',
            'maximum_consecutive_working_days': 'int',
            'minimum_shift_start_distance_minutes': 'int',
            'minimum_days_off_per_planning_period': 'int',
            'maximum_days_off_per_planning_period': 'int',
            'minimum_paid_minutes_per_planning_period': 'int',
            'maximum_paid_minutes_per_planning_period': 'int',
            'optional_days': 'SetWrapperDayOfWeek',
            'shift_start_variance_type': 'str',
            'shift_start_variances': 'ListWrapperShiftStartVariance',
            'shifts': 'list[WorkPlanShift]',
            'agents': 'list[DeletableUserReference]',
            'metadata': 'WfmVersionedEntityMetadata',
            'agent_count': 'int',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'enabled': 'enabled',
            'constrain_weekly_paid_time': 'constrainWeeklyPaidTime',
            'flexible_weekly_paid_time': 'flexibleWeeklyPaidTime',
            'weekly_exact_paid_minutes': 'weeklyExactPaidMinutes',
            'weekly_minimum_paid_minutes': 'weeklyMinimumPaidMinutes',
            'weekly_maximum_paid_minutes': 'weeklyMaximumPaidMinutes',
            'constrain_paid_time_granularity': 'constrainPaidTimeGranularity',
            'paid_time_granularity_minutes': 'paidTimeGranularityMinutes',
            'constrain_minimum_time_between_shifts': 'constrainMinimumTimeBetweenShifts',
            'minimum_time_between_shifts_minutes': 'minimumTimeBetweenShiftsMinutes',
            'maximum_days': 'maximumDays',
            'minimum_consecutive_non_working_minutes_per_week': 'minimumConsecutiveNonWorkingMinutesPerWeek',
            'constrain_maximum_consecutive_working_weekends': 'constrainMaximumConsecutiveWorkingWeekends',
            'maximum_consecutive_working_weekends': 'maximumConsecutiveWorkingWeekends',
            'minimum_working_days_per_week': 'minimumWorkingDaysPerWeek',
            'constrain_maximum_consecutive_working_days': 'constrainMaximumConsecutiveWorkingDays',
            'maximum_consecutive_working_days': 'maximumConsecutiveWorkingDays',
            'minimum_shift_start_distance_minutes': 'minimumShiftStartDistanceMinutes',
            'minimum_days_off_per_planning_period': 'minimumDaysOffPerPlanningPeriod',
            'maximum_days_off_per_planning_period': 'maximumDaysOffPerPlanningPeriod',
            'minimum_paid_minutes_per_planning_period': 'minimumPaidMinutesPerPlanningPeriod',
            'maximum_paid_minutes_per_planning_period': 'maximumPaidMinutesPerPlanningPeriod',
            'optional_days': 'optionalDays',
            'shift_start_variance_type': 'shiftStartVarianceType',
            'shift_start_variances': 'shiftStartVariances',
            'shifts': 'shifts',
            'agents': 'agents',
            'metadata': 'metadata',
            'agent_count': 'agentCount',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._enabled = None
        self._constrain_weekly_paid_time = None
        self._flexible_weekly_paid_time = None
        self._weekly_exact_paid_minutes = None
        self._weekly_minimum_paid_minutes = None
        self._weekly_maximum_paid_minutes = None
        self._constrain_paid_time_granularity = None
        self._paid_time_granularity_minutes = None
        self._constrain_minimum_time_between_shifts = None
        self._minimum_time_between_shifts_minutes = None
        self._maximum_days = None
        self._minimum_consecutive_non_working_minutes_per_week = None
        self._constrain_maximum_consecutive_working_weekends = None
        self._maximum_consecutive_working_weekends = None
        self._minimum_working_days_per_week = None
        self._constrain_maximum_consecutive_working_days = None
        self._maximum_consecutive_working_days = None
        self._minimum_shift_start_distance_minutes = None
        self._minimum_days_off_per_planning_period = None
        self._maximum_days_off_per_planning_period = None
        self._minimum_paid_minutes_per_planning_period = None
        self._maximum_paid_minutes_per_planning_period = None
        self._optional_days = None
        self._shift_start_variance_type = None
        self._shift_start_variances = None
        self._shifts = None
        self._agents = None
        self._metadata = None
        self._agent_count = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WorkPlanListItemResponse.
        The globally unique identifier for the object.

        :return: The id of this WorkPlanListItemResponse.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkPlanListItemResponse.
        The globally unique identifier for the object.

        :param id: The id of this WorkPlanListItemResponse.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WorkPlanListItemResponse.


        :return: The name of this WorkPlanListItemResponse.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkPlanListItemResponse.


        :param name: The name of this WorkPlanListItemResponse.
        :type: str
        """
        
        self._name = name

    @property
    def enabled(self):
        """
        Gets the enabled of this WorkPlanListItemResponse.
        Whether the work plan is enabled for scheduling

        :return: The enabled of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._enabled

    @enabled.setter
    def enabled(self, enabled):
        """
        Sets the enabled of this WorkPlanListItemResponse.
        Whether the work plan is enabled for scheduling

        :param enabled: The enabled of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._enabled = enabled

    @property
    def constrain_weekly_paid_time(self):
        """
        Gets the constrain_weekly_paid_time of this WorkPlanListItemResponse.
        Whether the weekly paid time constraint is enabled for this work plan

        :return: The constrain_weekly_paid_time of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._constrain_weekly_paid_time

    @constrain_weekly_paid_time.setter
    def constrain_weekly_paid_time(self, constrain_weekly_paid_time):
        """
        Sets the constrain_weekly_paid_time of this WorkPlanListItemResponse.
        Whether the weekly paid time constraint is enabled for this work plan

        :param constrain_weekly_paid_time: The constrain_weekly_paid_time of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._constrain_weekly_paid_time = constrain_weekly_paid_time

    @property
    def flexible_weekly_paid_time(self):
        """
        Gets the flexible_weekly_paid_time of this WorkPlanListItemResponse.
        Whether the weekly paid time constraint is flexible for this work plan

        :return: The flexible_weekly_paid_time of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._flexible_weekly_paid_time

    @flexible_weekly_paid_time.setter
    def flexible_weekly_paid_time(self, flexible_weekly_paid_time):
        """
        Sets the flexible_weekly_paid_time of this WorkPlanListItemResponse.
        Whether the weekly paid time constraint is flexible for this work plan

        :param flexible_weekly_paid_time: The flexible_weekly_paid_time of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._flexible_weekly_paid_time = flexible_weekly_paid_time

    @property
    def weekly_exact_paid_minutes(self):
        """
        Gets the weekly_exact_paid_minutes of this WorkPlanListItemResponse.
        Exact weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == false

        :return: The weekly_exact_paid_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._weekly_exact_paid_minutes

    @weekly_exact_paid_minutes.setter
    def weekly_exact_paid_minutes(self, weekly_exact_paid_minutes):
        """
        Sets the weekly_exact_paid_minutes of this WorkPlanListItemResponse.
        Exact weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == false

        :param weekly_exact_paid_minutes: The weekly_exact_paid_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._weekly_exact_paid_minutes = weekly_exact_paid_minutes

    @property
    def weekly_minimum_paid_minutes(self):
        """
        Gets the weekly_minimum_paid_minutes of this WorkPlanListItemResponse.
        Minimum weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == true

        :return: The weekly_minimum_paid_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._weekly_minimum_paid_minutes

    @weekly_minimum_paid_minutes.setter
    def weekly_minimum_paid_minutes(self, weekly_minimum_paid_minutes):
        """
        Sets the weekly_minimum_paid_minutes of this WorkPlanListItemResponse.
        Minimum weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == true

        :param weekly_minimum_paid_minutes: The weekly_minimum_paid_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._weekly_minimum_paid_minutes = weekly_minimum_paid_minutes

    @property
    def weekly_maximum_paid_minutes(self):
        """
        Gets the weekly_maximum_paid_minutes of this WorkPlanListItemResponse.
        Maximum weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == true

        :return: The weekly_maximum_paid_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._weekly_maximum_paid_minutes

    @weekly_maximum_paid_minutes.setter
    def weekly_maximum_paid_minutes(self, weekly_maximum_paid_minutes):
        """
        Sets the weekly_maximum_paid_minutes of this WorkPlanListItemResponse.
        Maximum weekly paid time in minutes for this work plan. Used if flexibleWeeklyPaidTime == true

        :param weekly_maximum_paid_minutes: The weekly_maximum_paid_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._weekly_maximum_paid_minutes = weekly_maximum_paid_minutes

    @property
    def constrain_paid_time_granularity(self):
        """
        Gets the constrain_paid_time_granularity of this WorkPlanListItemResponse.
        Whether paid time granularity is constrained for this work plan

        :return: The constrain_paid_time_granularity of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._constrain_paid_time_granularity

    @constrain_paid_time_granularity.setter
    def constrain_paid_time_granularity(self, constrain_paid_time_granularity):
        """
        Sets the constrain_paid_time_granularity of this WorkPlanListItemResponse.
        Whether paid time granularity is constrained for this work plan

        :param constrain_paid_time_granularity: The constrain_paid_time_granularity of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._constrain_paid_time_granularity = constrain_paid_time_granularity

    @property
    def paid_time_granularity_minutes(self):
        """
        Gets the paid_time_granularity_minutes of this WorkPlanListItemResponse.
        Granularity in minutes allowed for shift paid time in this work plan. Used if constrainPaidTimeGranularity == true

        :return: The paid_time_granularity_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._paid_time_granularity_minutes

    @paid_time_granularity_minutes.setter
    def paid_time_granularity_minutes(self, paid_time_granularity_minutes):
        """
        Sets the paid_time_granularity_minutes of this WorkPlanListItemResponse.
        Granularity in minutes allowed for shift paid time in this work plan. Used if constrainPaidTimeGranularity == true

        :param paid_time_granularity_minutes: The paid_time_granularity_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._paid_time_granularity_minutes = paid_time_granularity_minutes

    @property
    def constrain_minimum_time_between_shifts(self):
        """
        Gets the constrain_minimum_time_between_shifts of this WorkPlanListItemResponse.
        Whether the minimum time between shifts constraint is enabled for this work plan

        :return: The constrain_minimum_time_between_shifts of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._constrain_minimum_time_between_shifts

    @constrain_minimum_time_between_shifts.setter
    def constrain_minimum_time_between_shifts(self, constrain_minimum_time_between_shifts):
        """
        Sets the constrain_minimum_time_between_shifts of this WorkPlanListItemResponse.
        Whether the minimum time between shifts constraint is enabled for this work plan

        :param constrain_minimum_time_between_shifts: The constrain_minimum_time_between_shifts of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._constrain_minimum_time_between_shifts = constrain_minimum_time_between_shifts

    @property
    def minimum_time_between_shifts_minutes(self):
        """
        Gets the minimum_time_between_shifts_minutes of this WorkPlanListItemResponse.
        Minimum time between shifts in minutes defined in this work plan. Used if constrainMinimumTimeBetweenShifts == true

        :return: The minimum_time_between_shifts_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_time_between_shifts_minutes

    @minimum_time_between_shifts_minutes.setter
    def minimum_time_between_shifts_minutes(self, minimum_time_between_shifts_minutes):
        """
        Sets the minimum_time_between_shifts_minutes of this WorkPlanListItemResponse.
        Minimum time between shifts in minutes defined in this work plan. Used if constrainMinimumTimeBetweenShifts == true

        :param minimum_time_between_shifts_minutes: The minimum_time_between_shifts_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_time_between_shifts_minutes = minimum_time_between_shifts_minutes

    @property
    def maximum_days(self):
        """
        Gets the maximum_days of this WorkPlanListItemResponse.
        Maximum number days in a week allowed to be scheduled for this work plan

        :return: The maximum_days of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._maximum_days

    @maximum_days.setter
    def maximum_days(self, maximum_days):
        """
        Sets the maximum_days of this WorkPlanListItemResponse.
        Maximum number days in a week allowed to be scheduled for this work plan

        :param maximum_days: The maximum_days of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._maximum_days = maximum_days

    @property
    def minimum_consecutive_non_working_minutes_per_week(self):
        """
        Gets the minimum_consecutive_non_working_minutes_per_week of this WorkPlanListItemResponse.
        Minimum amount of consecutive non working minutes per week that agents who are assigned this work plan are allowed to have off

        :return: The minimum_consecutive_non_working_minutes_per_week of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_consecutive_non_working_minutes_per_week

    @minimum_consecutive_non_working_minutes_per_week.setter
    def minimum_consecutive_non_working_minutes_per_week(self, minimum_consecutive_non_working_minutes_per_week):
        """
        Sets the minimum_consecutive_non_working_minutes_per_week of this WorkPlanListItemResponse.
        Minimum amount of consecutive non working minutes per week that agents who are assigned this work plan are allowed to have off

        :param minimum_consecutive_non_working_minutes_per_week: The minimum_consecutive_non_working_minutes_per_week of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_consecutive_non_working_minutes_per_week = minimum_consecutive_non_working_minutes_per_week

    @property
    def constrain_maximum_consecutive_working_weekends(self):
        """
        Gets the constrain_maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        Whether to constrain the maximum consecutive working weekends

        :return: The constrain_maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._constrain_maximum_consecutive_working_weekends

    @constrain_maximum_consecutive_working_weekends.setter
    def constrain_maximum_consecutive_working_weekends(self, constrain_maximum_consecutive_working_weekends):
        """
        Sets the constrain_maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        Whether to constrain the maximum consecutive working weekends

        :param constrain_maximum_consecutive_working_weekends: The constrain_maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._constrain_maximum_consecutive_working_weekends = constrain_maximum_consecutive_working_weekends

    @property
    def maximum_consecutive_working_weekends(self):
        """
        Gets the maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        The maximum number of consecutive weekends that agents who are assigned to this work plan are allowed to work

        :return: The maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._maximum_consecutive_working_weekends

    @maximum_consecutive_working_weekends.setter
    def maximum_consecutive_working_weekends(self, maximum_consecutive_working_weekends):
        """
        Sets the maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        The maximum number of consecutive weekends that agents who are assigned to this work plan are allowed to work

        :param maximum_consecutive_working_weekends: The maximum_consecutive_working_weekends of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._maximum_consecutive_working_weekends = maximum_consecutive_working_weekends

    @property
    def minimum_working_days_per_week(self):
        """
        Gets the minimum_working_days_per_week of this WorkPlanListItemResponse.
        The minimum number of days that agents assigned to a work plan must work per week

        :return: The minimum_working_days_per_week of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_working_days_per_week

    @minimum_working_days_per_week.setter
    def minimum_working_days_per_week(self, minimum_working_days_per_week):
        """
        Sets the minimum_working_days_per_week of this WorkPlanListItemResponse.
        The minimum number of days that agents assigned to a work plan must work per week

        :param minimum_working_days_per_week: The minimum_working_days_per_week of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_working_days_per_week = minimum_working_days_per_week

    @property
    def constrain_maximum_consecutive_working_days(self):
        """
        Gets the constrain_maximum_consecutive_working_days of this WorkPlanListItemResponse.
        Whether to constrain the maximum consecutive working days

        :return: The constrain_maximum_consecutive_working_days of this WorkPlanListItemResponse.
        :rtype: bool
        """
        return self._constrain_maximum_consecutive_working_days

    @constrain_maximum_consecutive_working_days.setter
    def constrain_maximum_consecutive_working_days(self, constrain_maximum_consecutive_working_days):
        """
        Sets the constrain_maximum_consecutive_working_days of this WorkPlanListItemResponse.
        Whether to constrain the maximum consecutive working days

        :param constrain_maximum_consecutive_working_days: The constrain_maximum_consecutive_working_days of this WorkPlanListItemResponse.
        :type: bool
        """
        
        self._constrain_maximum_consecutive_working_days = constrain_maximum_consecutive_working_days

    @property
    def maximum_consecutive_working_days(self):
        """
        Gets the maximum_consecutive_working_days of this WorkPlanListItemResponse.
        The maximum number of consecutive days that agents assigned to this work plan are allowed to work. Used if constrainMaximumConsecutiveWorkingDays == true

        :return: The maximum_consecutive_working_days of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._maximum_consecutive_working_days

    @maximum_consecutive_working_days.setter
    def maximum_consecutive_working_days(self, maximum_consecutive_working_days):
        """
        Sets the maximum_consecutive_working_days of this WorkPlanListItemResponse.
        The maximum number of consecutive days that agents assigned to this work plan are allowed to work. Used if constrainMaximumConsecutiveWorkingDays == true

        :param maximum_consecutive_working_days: The maximum_consecutive_working_days of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._maximum_consecutive_working_days = maximum_consecutive_working_days

    @property
    def minimum_shift_start_distance_minutes(self):
        """
        Gets the minimum_shift_start_distance_minutes of this WorkPlanListItemResponse.
        The time period in minutes for the duration between the start times of two consecutive working days

        :return: The minimum_shift_start_distance_minutes of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_shift_start_distance_minutes

    @minimum_shift_start_distance_minutes.setter
    def minimum_shift_start_distance_minutes(self, minimum_shift_start_distance_minutes):
        """
        Sets the minimum_shift_start_distance_minutes of this WorkPlanListItemResponse.
        The time period in minutes for the duration between the start times of two consecutive working days

        :param minimum_shift_start_distance_minutes: The minimum_shift_start_distance_minutes of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_shift_start_distance_minutes = minimum_shift_start_distance_minutes

    @property
    def minimum_days_off_per_planning_period(self):
        """
        Gets the minimum_days_off_per_planning_period of this WorkPlanListItemResponse.
        Minimum days off in the planning period

        :return: The minimum_days_off_per_planning_period of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_days_off_per_planning_period

    @minimum_days_off_per_planning_period.setter
    def minimum_days_off_per_planning_period(self, minimum_days_off_per_planning_period):
        """
        Sets the minimum_days_off_per_planning_period of this WorkPlanListItemResponse.
        Minimum days off in the planning period

        :param minimum_days_off_per_planning_period: The minimum_days_off_per_planning_period of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_days_off_per_planning_period = minimum_days_off_per_planning_period

    @property
    def maximum_days_off_per_planning_period(self):
        """
        Gets the maximum_days_off_per_planning_period of this WorkPlanListItemResponse.
        Maximum days off in the planning period

        :return: The maximum_days_off_per_planning_period of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._maximum_days_off_per_planning_period

    @maximum_days_off_per_planning_period.setter
    def maximum_days_off_per_planning_period(self, maximum_days_off_per_planning_period):
        """
        Sets the maximum_days_off_per_planning_period of this WorkPlanListItemResponse.
        Maximum days off in the planning period

        :param maximum_days_off_per_planning_period: The maximum_days_off_per_planning_period of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._maximum_days_off_per_planning_period = maximum_days_off_per_planning_period

    @property
    def minimum_paid_minutes_per_planning_period(self):
        """
        Gets the minimum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        Minimum paid minutes in the planning period

        :return: The minimum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._minimum_paid_minutes_per_planning_period

    @minimum_paid_minutes_per_planning_period.setter
    def minimum_paid_minutes_per_planning_period(self, minimum_paid_minutes_per_planning_period):
        """
        Sets the minimum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        Minimum paid minutes in the planning period

        :param minimum_paid_minutes_per_planning_period: The minimum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._minimum_paid_minutes_per_planning_period = minimum_paid_minutes_per_planning_period

    @property
    def maximum_paid_minutes_per_planning_period(self):
        """
        Gets the maximum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        Maximum paid minutes in the planning period

        :return: The maximum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._maximum_paid_minutes_per_planning_period

    @maximum_paid_minutes_per_planning_period.setter
    def maximum_paid_minutes_per_planning_period(self, maximum_paid_minutes_per_planning_period):
        """
        Sets the maximum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        Maximum paid minutes in the planning period

        :param maximum_paid_minutes_per_planning_period: The maximum_paid_minutes_per_planning_period of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._maximum_paid_minutes_per_planning_period = maximum_paid_minutes_per_planning_period

    @property
    def optional_days(self):
        """
        Gets the optional_days of this WorkPlanListItemResponse.
        Optional days to schedule for this work plan. Populate with expand=details

        :return: The optional_days of this WorkPlanListItemResponse.
        :rtype: SetWrapperDayOfWeek
        """
        return self._optional_days

    @optional_days.setter
    def optional_days(self, optional_days):
        """
        Sets the optional_days of this WorkPlanListItemResponse.
        Optional days to schedule for this work plan. Populate with expand=details

        :param optional_days: The optional_days of this WorkPlanListItemResponse.
        :type: SetWrapperDayOfWeek
        """
        
        self._optional_days = optional_days

    @property
    def shift_start_variance_type(self):
        """
        Gets the shift_start_variance_type of this WorkPlanListItemResponse.
        This constraint ensures that an agent starts each workday within a user-defined time threshold

        :return: The shift_start_variance_type of this WorkPlanListItemResponse.
        :rtype: str
        """
        return self._shift_start_variance_type

    @shift_start_variance_type.setter
    def shift_start_variance_type(self, shift_start_variance_type):
        """
        Sets the shift_start_variance_type of this WorkPlanListItemResponse.
        This constraint ensures that an agent starts each workday within a user-defined time threshold

        :param shift_start_variance_type: The shift_start_variance_type of this WorkPlanListItemResponse.
        :type: str
        """
        allowed_values = ["ShiftStart", "ShiftStartAndPaidDuration"]
        if shift_start_variance_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for shift_start_variance_type -> " + shift_start_variance_type)
            self._shift_start_variance_type = "outdated_sdk_version"
        else:
            self._shift_start_variance_type = shift_start_variance_type

    @property
    def shift_start_variances(self):
        """
        Gets the shift_start_variances of this WorkPlanListItemResponse.
        Variance in minutes among start times of shifts in this work plan. Populate with expand=details

        :return: The shift_start_variances of this WorkPlanListItemResponse.
        :rtype: ListWrapperShiftStartVariance
        """
        return self._shift_start_variances

    @shift_start_variances.setter
    def shift_start_variances(self, shift_start_variances):
        """
        Sets the shift_start_variances of this WorkPlanListItemResponse.
        Variance in minutes among start times of shifts in this work plan. Populate with expand=details

        :param shift_start_variances: The shift_start_variances of this WorkPlanListItemResponse.
        :type: ListWrapperShiftStartVariance
        """
        
        self._shift_start_variances = shift_start_variances

    @property
    def shifts(self):
        """
        Gets the shifts of this WorkPlanListItemResponse.
        Shifts in this work plan. Populate with expand=details (defaults to empty list)

        :return: The shifts of this WorkPlanListItemResponse.
        :rtype: list[WorkPlanShift]
        """
        return self._shifts

    @shifts.setter
    def shifts(self, shifts):
        """
        Sets the shifts of this WorkPlanListItemResponse.
        Shifts in this work plan. Populate with expand=details (defaults to empty list)

        :param shifts: The shifts of this WorkPlanListItemResponse.
        :type: list[WorkPlanShift]
        """
        
        self._shifts = shifts

    @property
    def agents(self):
        """
        Gets the agents of this WorkPlanListItemResponse.
        Agents in this work plan. Populate with expand=details (defaults to empty list)

        :return: The agents of this WorkPlanListItemResponse.
        :rtype: list[DeletableUserReference]
        """
        return self._agents

    @agents.setter
    def agents(self, agents):
        """
        Sets the agents of this WorkPlanListItemResponse.
        Agents in this work plan. Populate with expand=details (defaults to empty list)

        :param agents: The agents of this WorkPlanListItemResponse.
        :type: list[DeletableUserReference]
        """
        
        self._agents = agents

    @property
    def metadata(self):
        """
        Gets the metadata of this WorkPlanListItemResponse.
        Version metadata for this work plan

        :return: The metadata of this WorkPlanListItemResponse.
        :rtype: WfmVersionedEntityMetadata
        """
        return self._metadata

    @metadata.setter
    def metadata(self, metadata):
        """
        Sets the metadata of this WorkPlanListItemResponse.
        Version metadata for this work plan

        :param metadata: The metadata of this WorkPlanListItemResponse.
        :type: WfmVersionedEntityMetadata
        """
        
        self._metadata = metadata

    @property
    def agent_count(self):
        """
        Gets the agent_count of this WorkPlanListItemResponse.
        Number of agents in this work plan.  Populate with expand=agentCount

        :return: The agent_count of this WorkPlanListItemResponse.
        :rtype: int
        """
        return self._agent_count

    @agent_count.setter
    def agent_count(self, agent_count):
        """
        Sets the agent_count of this WorkPlanListItemResponse.
        Number of agents in this work plan.  Populate with expand=agentCount

        :param agent_count: The agent_count of this WorkPlanListItemResponse.
        :type: int
        """
        
        self._agent_count = agent_count

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WorkPlanListItemResponse.
        The URI for this object

        :return: The self_uri of this WorkPlanListItemResponse.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WorkPlanListItemResponse.
        The URI for this object

        :param self_uri: The self_uri of this WorkPlanListItemResponse.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

